@@ -13,11 +13,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
- squidview 0.6
+ squidview 0.7
  
  A program to nicely browse your squid log
   
- (c) 2001 - 2004 Graeme Sheppard
+ (c) 2001 - 2006 Graeme Sheppard
 
  */
 
@@ -25,6 +25,7 @@
 #include <config.h>
 #endif
 
+#include <stdio.h>
 #include <curses.h>
 #include <time.h>
 #include <string>
@@ -83,6 +84,8 @@ const char szHowToFile[] = "HOWTO";      // link name
 
 string sLogFile1, sLogFile2, sLogFile3;
 string sWordFile, sUsersFile, sAliasesFile, sSetFileName, sHowToLink;
+FILE *fReadingFile = 0;
+char const *pszReadingFile = 0;
 
 string sViewer = "less";
 string sCurrentReport = "";
